"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@heroku-cli/command");
const core_1 = require("@oclif/core");
const yeoman_environment_1 = require("yeoman-environment");
const base_1 = tslib_1.__importDefault(require("../../lib/base"));
class Project extends base_1.default {
    static description = 'generates a Heroku Integration project template';
    static flags = {
        language: command_1.flags.string({
            char: 'l',
            default: 'javascript', // TODO: remove after adding more languages
            description: 'language (one of: javascript, …)',
            hidden: true, // TODO: remove after adding more languages
            options: ['javascript'],
        }),
        'output-directory': command_1.flags.string({
            char: 'o',
            description: 'output directory where files will be placed (defaults to ./{PROJECT_NAME})',
        }),
        'project-type': command_1.flags.string({
            char: 't',
            default: 'salesforce', // TODO: remove after adding more project types
            description: 'project type (one of: salesforce, …)',
            hidden: true, // TODO: remove after adding more project types
            options: ['salesforce'],
        }),
    };
    static args = {
        project_name: core_1.Args.string({ description: 'user assigned project name', required: true }),
    };
    static yeomanEnvCreator = yeoman_environment_1.createEnv;
    async run() {
        const { flags, args } = await this.parse(Project);
        const { language, 'project-type': projectType, 'output-directory': outputDirectory } = flags;
        const { project_name: projectName } = args;
        const yeomanEnv = Project.yeomanEnvCreator();
        yeomanEnv.lookup({ localOnly: true, packagePatterns: ['@heroku/generator-*'] });
        await yeomanEnv.run(`@heroku/heroku-integration:${projectType}-${language}`, {
            projectName,
            outputDirectory: outputDirectory || `./${projectName}`,
        });
    }
}
exports.default = Project;
