"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const color_1 = require("@heroku-cli/color");
const command_1 = require("@heroku-cli/command");
const core_1 = require("@oclif/core");
const tsheredoc_1 = tslib_1.__importDefault(require("tsheredoc"));
class default_1 extends command_1.Command {
    _integration;
    _addonId;
    get addonServiceSlug() {
        return process.env.HEROKU_INTEGRATION_ADDON || 'heroku-integration';
    }
    get apiUrlConfigVarName() {
        return `${this.addonServiceSlug.replace(/-/g, '_').toUpperCase()}_API_URL`;
    }
    get integration() {
        if (this._integration)
            return this._integration;
        core_1.ux.error((0, tsheredoc_1.default) `
        Heroku Integration API Client not configured.
        Did you call ${color_1.color.yellow('await this.configureIntegrationClient(app, this.config)')} before accessing ${color_1.color.yellow('this.integration')}?
      `, { exit: 1 });
    }
    get addonId() {
        return this._addonId || '';
    }
    async configureIntegrationClient(app) {
        if (this._integration)
            return;
        const addonsRequest = this.heroku.get(`/apps/${app}/addons`);
        const configVarsRequest = this.heroku.get(`/apps/${app}/config-vars`);
        const [{ body: addons }, { body: configVars }] = await Promise.all([addonsRequest, configVarsRequest]);
        const addon = addons.find(addon => addon.addon_service.name === this.addonServiceSlug);
        if (!addon) {
            core_1.ux.error((0, tsheredoc_1.default) `
          Heroku Integration add-on isn’t present on ${color_1.color.app(app)}.
          Install the add-on using ${color_1.color.cmd(`heroku addons:create ${this.addonServiceSlug} -a ${app}`)}.
        `, { exit: 1 });
        }
        const apiUrl = configVars[this.apiUrlConfigVarName];
        if (!apiUrl) {
            core_1.ux.error((0, tsheredoc_1.default) `
          Heroku Integration add-on isn’t fully provisioned on ${color_1.color.app(app)}.
          Wait for the add-on to finish provisioning with ${color_1.color.cmd(`heroku addons:wait ${this.addonServiceSlug} -a ${app}`)}.
        `, { exit: 1 });
        }
        const baseUrl = new URL(apiUrl);
        const client = new command_1.APIClient(this.config);
        client.defaults.host = baseUrl.hostname;
        client.defaults.headers = {
            ...this.heroku.defaults.headers,
            accept: 'application/json',
            'user-agent': `heroku-cli-plugin-integration/${this.config.version} ${this.config.platform}`,
        };
        const matchedAddonId = baseUrl.pathname.match(/addons\/([^/]+)/);
        this._addonId = matchedAddonId ? matchedAddonId[1] : '';
        this._integration = client;
    }
}
exports.default = default_1;
